# == Schema Information
#
# Table name: contests
#
#  id                 :integer          not null, primary key
#  allow_registration :boolean          default(FALSE)
#  name               :string
#  slug               :string
#  team               :boolean          default(FALSE)
#  created_at         :datetime         not null
#  updated_at         :datetime         not null
#  user_id            :integer          not null
#
# Indexes
#
#  index_contests_on_user_id  (user_id)
#
# Foreign Keys
#
#  user_id  (user_id => users.id)
#
class Contest < ApplicationRecord
  belongs_to :user

  has_many :completions, dependent: :destroy
  has_many :contestants, dependent: :destroy
  has_many :puzzles, dependent: :destroy

  validates :name, presence: true
  validates :slug, presence: true, format: { with: /\A(\w|-)*\z/, message: 'Only alphanumeric characters, "-" and "_" allowed.' }
end
